@@ -10,8 +10,8 @@ with 'App::Netdisco::Daemon::Worker::Common';
 with 'App::Netdisco::Daemon::Worker::Interactive::DeviceActions',
      'App::Netdisco::Daemon::Worker::Interactive::PortActions';
 
-sub worker_type { 'int' }
-sub worker_name { 'Interactive' }
+sub worker_tag  { 'int' }
+sub worker_type { 'Interactive' }
 sub munge_action { 'set_' . $_[1] }
 
 1;
